# -*- coding: utf-8 -*-

import os
import wx
import re
import sys
import time

import wx.lib.mixins.listctrl as listmix

import config
import tray_main
import lib_sqlite

import f_todo_add
import f_todo_edit

def create():
    return Frame1()

class TodoList(wx.ListCtrl, listmix.ListCtrlAutoWidthMixin):
    def __init__(self, parent, ID, pos=wx.DefaultPosition, size=wx.DefaultSize, style=0):
        wx.ListCtrl.__init__(self, parent, ID, pos, size, style)
        listmix.ListCtrlAutoWidthMixin.__init__(self)

class Frame1(wx.Frame, listmix.ColumnSorterMixin):
    DB_DIR = os.path.join(os.path.expanduser("~"), ".wxtodo")
    
    def __init__(self):
        wx.Frame.__init__(self, None, id=-1, name='wxTodo - Übersicht',
                          size=wx.Size(850, 600), style=wx.DEFAULT_FRAME_STYLE, title='wxTodo - Übersicht')
        
        if not os.path.isdir(self.DB_DIR):
            os.mkdir(self.DB_DIR)
            
        self.todolistdata = {}

        self.DBlite = lib_sqlite.DBlite(os.path.join(self.DB_DIR, "wxtodo.db"))
        
        self.tray = tray_main.TrayIcon(self, self.DBlite)
        
        self.SetMinSize((850,600))
        self.Centre()
        
        self.__gui_init()
        self._TodoList_refresh()

        self.Bind(wx.EVT_CLOSE, self.OnClose)
        
    def __gui_init(self):
        panel_main = wx.Panel(self, -1)
        box_v = wx.BoxSizer(wx.VERTICAL)
        fontb = wx.Font(10, wx.NORMAL, wx.NORMAL, wx.FONTWEIGHT_BOLD)
        
        box_v.AddSpacer(5)
        
        # Reihe Titel
        box_h_1 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_1.AddSpacer(5)
        sttext1 = wx.StaticText(panel_main, -1, "Todo Gesamtübersicht: ")
        sttext1.SetFont(fontb)
        box_h_1.Add(sttext1, 0, wx.CENTER)
        box_h_1.AddSpacer(5)
        box_v.Add(box_h_1, 0, wx.EXPAND)
        
        box_v.AddSpacer(10)
        
        # Reihe Suche
        box = wx.StaticBox(panel_main, -1, "Suche")
        box_h_1 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_1.AddSpacer(5)
        ## Spalte Kurztitel
        sttext1 = wx.StaticText(panel_main, -1, "Kurztitel: ")
        box_h_1.Add(sttext1, 0, wx.CENTER)
        box_h_1.AddSpacer(5)
        self.TodoFilterTitle = wx.TextCtrl(panel_main, -1, "")
        self.TodoFilterTitle.Bind(wx.EVT_KEY_UP, self.OnTlistReload)
        box_h_1.Add(self.TodoFilterTitle, 1, wx.EXPAND)
        box_h_1.AddSpacer(5)
        ## Spalte Beschreibung
        sttext1 = wx.StaticText(panel_main, -1, "Beschreibung: ")
        box_h_1.Add(sttext1, 0, wx.CENTER)
        box_h_1.AddSpacer(5)
        self.TodoFilterText = wx.TextCtrl(panel_main, -1, "")
        self.TodoFilterText.Bind(wx.EVT_KEY_UP, self.OnTlistReload)
        box_h_1.Add(self.TodoFilterText, 1, wx.EXPAND)
        box_h_1.AddSpacer(5)
        ## Spalte Priorität
        sttext1 = wx.StaticText(panel_main, -1, "Priorität: ")
        box_h_1.Add(sttext1, 0, wx.CENTER)
        box_h_1.AddSpacer(5)
        self.TodoFilterPriority = wx.Choice(panel_main, -1)
        self.TodoFilterPriority.Bind(wx.EVT_CHOICE, self.OnTlistReload)
        self.TodoFilterPriority.Append("")
        self.TodoFilterPriority.SetClientData(0, "")
        for i in xrange(1,11):
            self.TodoFilterPriority.Append(str(i))
            self.TodoFilterPriority.SetClientData(i, i)
        self.TodoFilterPriority.SetSelection(0)
        box_h_1.Add(self.TodoFilterPriority, 0)
        box_h_1.AddSpacer(5)
        ## Spalte Status
        sttext1 = wx.StaticText(panel_main, -1, "Status: ")
        box_h_1.Add(sttext1, 0, wx.CENTER)
        box_h_1.AddSpacer(5)
        self.TodoFilterStatus = wx.Choice(panel_main, -1)
        self.TodoFilterStatus.Bind(wx.EVT_CHOICE, self.OnTlistReload)
        self.TodoFilterStatus.Append("")
        self.TodoFilterStatus.SetClientData(0, "")
        i = 1
        for item_id in config.TODO_AVAIL_STATUS:
            self.TodoFilterStatus.Append(config.TODO_AVAIL_STATUS[item_id])
            self.TodoFilterStatus.SetClientData(i, item_id)
            i = i + 1
        self.TodoFilterStatus.Append("!= Abgeschlossen")
        self.TodoFilterStatus.SetClientData(i, -2)
        self.TodoFilterStatus.SetSelection(0)
        box_h_1.Add(self.TodoFilterStatus, 0)
        box_h_1.AddSpacer(5)
        bsizer = wx.StaticBoxSizer(box, wx.VERTICAL)
        bsizer.Add(box_h_1, 0, wx.EXPAND|wx.ALL, 5)
        box_v.Add(bsizer, 0, wx.EXPAND|wx.ALL, 5)
        
        box_v.AddSpacer(5)
        
        # Reihe Anzeige
        box_h_1 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_1.AddSpacer(5)
        self.Tlist = TodoList(panel_main, -1, style=wx.LC_REPORT | wx.BORDER_NONE  | wx.LC_SORT_ASCENDING)
        self.Tlist.Bind(wx.EVT_LIST_ITEM_ACTIVATED, self.OnTlistSelected)
        self.Tlist.Bind(wx.EVT_LIST_KEY_DOWN, self.OnTListKeyDown)
        box_h_1.Add(self.Tlist, 1, wx.EXPAND)
        box_h_1.AddSpacer(5)
        box_v.Add(box_h_1, 1, wx.EXPAND)
        
        box_v.AddSpacer(5)
        
        # Reihe Toolbar
        box_h_5_5 = wx.BoxSizer(wx.HORIZONTAL)
        
        box_v_2_2 = wx.BoxSizer(wx.VERTICAL)
        box_h_5_2 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_5_2.AddSpacer(5)
        self.btn_delete = wx.Button(panel_main, -1, "Löschen", style=wx.BU_EXACTFIT, size = (100,-1))
        box_h_5_2.Add(self.btn_delete, 1, wx.ALIGN_LEFT)
        box_v_2_2.Add(box_h_5_2, 1, wx.ALIGN_LEFT)
        box_h_5_5.Add(box_v_2_2, 0)
        
        box_v_5_2 = wx.BoxSizer(wx.VERTICAL)
        box_h_5 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_5.AddSpacer(5)
        self.btn_hide = wx.Button(panel_main, -1, "Fenster verstecken", style=wx.BU_EXACTFIT, size = (-1,-1))
        box_h_5.Add(self.btn_hide, 0)
        self.btn_new = wx.Button(panel_main, -1, "Neues Todo", style=wx.BU_EXACTFIT, size = (100,-1))
        box_h_5.Add(self.btn_new, 0)
        self.btn_edit = wx.Button(panel_main, -1, "Bearbeiten", style=wx.BU_EXACTFIT, size = (100,-1))
        box_h_5.Add(self.btn_edit, 0)
        box_h_5.AddSpacer(5)
        box_v_5_2.Add(box_h_5, 1, wx.ALIGN_RIGHT)
        box_h_5_5.Add(box_v_5_2, 1)
        
        self.Bind(wx.EVT_BUTTON, self.OnBtnDelete, self.btn_delete)
        self.Bind(wx.EVT_BUTTON, self.OnBtnHide, self.btn_hide)
        self.Bind(wx.EVT_BUTTON, self.OnBtnNew, self.btn_new)
        self.Bind(wx.EVT_BUTTON, self.OnBtnEdit, self.btn_edit)
        
        box_v.Add(box_h_5_5, 0, wx.EXPAND)
        
        box_v.AddSpacer(5)
        
        panel_main.SetAutoLayout(True)
        panel_main.SetSizer(box_v, False)
        panel_main.Layout()
        
        box_vm = wx.BoxSizer(wx.VERTICAL)
        box_vm.Add(panel_main, 1, wx.EXPAND)
        
        self.SetAutoLayout(True)
        self.SetSizer(box_vm, False)
        self.Layout()
        
    def _TodoList_refresh(self):
        revert_status = ""
        
        FilterTitle = self.TodoFilterTitle.GetValue()
        FilterText = self.TodoFilterText.GetValue()
        FilterPriority = self.TodoFilterPriority.GetClientData(self.TodoFilterPriority.GetSelection())
        FilterStatus = self.TodoFilterStatus.GetClientData(self.TodoFilterStatus.GetSelection())
        
        print FilterStatus
        
        if FilterStatus == -2:
            revert_status = "not"
            FilterStatus = "2"
        
        if FilterTitle == "": FilterTitle = "%"
        if FilterText == "": FilterText = "%"
        if FilterPriority == "": FilterPriority = "%"
        if FilterStatus == "": FilterStatus = "%"
        
        FilterTitle = "%" + FilterTitle + "%"
        FilterText = "%" + FilterText + "%"
        
        self.Tlist.ClearAll()
        
        self.Tlist.InsertColumn(0, "Kurztitel")
        self.Tlist.InsertColumn(1, "Beschreibung")
        self.Tlist.InsertColumn(2, "Priorität")
        self.Tlist.InsertColumn(3, "Status")
        
        sql_tlist_data = self.DBlite.cursor.execute("SELECT * from todos WHERE short_title like ? and text like ? and priority like ? and status %s like ? ORDER BY priority DESC" % revert_status, (FilterTitle, FilterText, FilterPriority, FilterStatus)).fetchall()
        
        i = 0
        for row in sql_tlist_data:
            id, short_title = row[0], row[2]
            text, priority, status = row[3][:50], row[4], row[5]
            
            self.todolistdata[id] = [short_title, text, priority, status]
            
            index = self.Tlist.InsertStringItem(sys.maxint, short_title)
            self.Tlist.SetStringItem(index, 1, text)
            self.Tlist.SetStringItem(index, 2, str(priority))
            try: self.Tlist.SetStringItem(index, 3, config.TODO_AVAIL_STATUS[status])
            except: self.Tlist.SetStringItem(index, 3, "Unbekannt")
            self.Tlist.SetItemData(index, id)
            
            i += 1
            
        if i == 0:
            index = self.Tlist.InsertStringItem(sys.maxint, "Keine Einträge zur Suche gefunden!")
            self.Tlist.SetItemData(index, -1)
            
        self.Tlist.SetColumnWidth(0, 330)
        self.Tlist.SetColumnWidth(1, 330)
        self.Tlist.SetColumnWidth(2, 60)
        self.Tlist.SetColumnWidth(3, 120)
        
        self.itemDataMap = self.todolistdata
        
        listmix.ColumnSorterMixin.__init__(self, 4)
        
    def _getSelItemT(self):
        item = -1
        while 1:
            item = self.Tlist.GetNextItem(item, wx.LIST_NEXT_ALL, wx.LIST_STATE_SELECTED);
            
            if item == -1:
                break
            
            return item
        
    # Used by the ColumnSorterMixin, see wx/lib/mixins/listctrl.py
    def GetListCtrl(self):
        return self.Tlist

    # Used by the ColumnSorterMixin, see wx/lib/mixins/listctrl.py
    def GetSortImages(self):
        #return (self.sm_dn, self.sm_up)
        pass         
    
    def OnTlistReload(self, evt):
        self._TodoList_refresh() 
    
    def OnTlistSelected(self, evt):
        self.OnBtnEdit(evt)
        
    def OnTListKeyDown(self, evt):
        selItem = self._getSelItemT()
        try: selItemID = self.Tlist.GetItemData(selItem)
        except: return
        #
        # Todo löschen
        if evt.GetCode() == 127:
            self.OnBtnDelete(evt)
        else:
            evet.Skip()
    
    def OnBtnDelete(self, evt):
        selItem = self._getSelItemT()
        
        if selItem == None:
            dlg = wx.MessageDialog(self, 'Kein Todo zum Löschen gewählt!',
                                   'wxTodo', wx.OK | wx.ICON_INFORMATION)
            selected = dlg.ShowModal()
            dlg.Destroy()
        else:
            selItemID = self.Tlist.GetItemData(selItem)
            
            if selItemID != -1:
                dlg = wx.MessageDialog(self, 'ACHTUNG! Das gewählte Todo wird unwiderruflich gelöscht!',
                                       'wxTodo', wx.OK | wx.CANCEL | wx.ICON_WARNING)
                selected = dlg.ShowModal()
                dlg.Destroy()
                
                if selected == 5100:
                    self.DBlite.todo_del(selItemID)
                    self._TodoList_refresh()
                
    def OnBtnHide(self, evt):
        if self.IsShown():
            self.Show(False)
    
    def OnBtnNew(self, evt):
        self.f_todo_add = f_todo_add.create(self, self.DBlite)
        self.f_todo_add.Show()
        self.f_todo_add.SetFocus()
    
    def OnBtnEdit(self, evt):
        selItem = self._getSelItemT()
        if selItem == None:
            dlg = wx.MessageDialog(self, 'Kein Todo zum Anzeigen/Bearbeiten gewählt!',
                                   'wxTodo', wx.OK | wx.ICON_INFORMATION)
            selected = dlg.ShowModal()
            dlg.Destroy()
        else:
            selItemID = self.Tlist.GetItemData(selItem)
            
            if selItemID != -1:
                self.f_todo_edit = f_todo_edit.create(self, self.DBlite, selItemID)
                self.f_todo_edit.Show()

    def OnClose(self, event):
        self.Hide()