# -*- coding: utf-8 -*-

import os
import wx
import re
import sys
import time

def create(parent_frame, db):
    return Frame2(parent_frame, db)

class Frame2(wx.Frame):
    SAVE_LOCK = True
    
    def __init__(self, parent_frame, db):
        self.db = db
        self.parent_frame = parent_frame
        
        self.__gui_init()
        
    def __gui_init(self):
        wx.Frame.__init__(self, self.parent_frame, id=-1, name='wxTodo - Todo hinzufügen',
                          size=wx.Size(700, 400), style=wx.DEFAULT_FRAME_STYLE, title='wxTodo - Todo hinzufügen')
        
        self.SetMinSize((700, 400))
        
        panel_main = wx.Panel(self, -1)
        box_v = wx.BoxSizer(wx.VERTICAL)
        fontb = wx.Font(10, wx.NORMAL, wx.NORMAL, wx.FONTWEIGHT_BOLD)
        
        box_v.AddSpacer(5)
        
        # Reihe Titel
        box_h_1 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_1.AddSpacer(5)
        sttext1 = wx.StaticText(panel_main, -1, "Titel: ", size = (150,-1))
        box_h_1.Add(sttext1, 0, wx.CENTER)
        self.tc_title = wx.TextCtrl(panel_main, -1, "")
        self.tc_title.Bind(wx.EVT_KEY_UP, self.__unlock_save)
        box_h_1.Add(self.tc_title, 1, wx.EXPAND)
        box_h_1.AddSpacer(5)
        box_v.Add(box_h_1, 0, wx.EXPAND)
        
        box_v.AddSpacer(5)
        
        # Reihe Kurz-Titel
        box_h_2 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_2.AddSpacer(5)
        sttext2 = wx.StaticText(panel_main, -1, "Kurz-Titel: ", size = (150,-1))
        box_h_2.Add(sttext2, 0, wx.CENTER)
        self.tc_short_title = wx.TextCtrl(panel_main, -1, "")
        self.tc_short_title.Bind(wx.EVT_KEY_UP, self.__unlock_save)
        box_h_2.Add(self.tc_short_title, 1, wx.EXPAND)
        box_h_2.AddSpacer(5)
        box_v.Add(box_h_2, 0, wx.EXPAND)
        
        box_v.AddSpacer(5)
        
        # Reihe Priorität
        box_h_3 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_3.AddSpacer(5)
        sttext3 = wx.StaticText(panel_main, -1, "Priorität: ", size = (150,-1))
        box_h_3.Add(sttext3, 0, wx.CENTER)
        self.ch_priority = wx.Choice(panel_main, -1, size = (100,-1))
        self.ch_priority.Bind(wx.EVT_CHOICE, self.__unlock_save)
        for i in xrange(1,11):
            self.ch_priority.Append(str(i))
        box_h_3.Add(self.ch_priority, 0)
        box_h_3.AddSpacer(5)
        box_v.Add(box_h_3, 0, wx.EXPAND)
        
        box_v.AddSpacer(5)
        
        # Reihe Text
        box_h_4 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_4.AddSpacer(5)
        sttext4 = wx.StaticText(panel_main, -1, "Beschreibung: ", size = (150,-1))
        box_h_4.Add(sttext4, 0, wx.CENTER)
        self.tc_text = wx.TextCtrl(panel_main, -1, "", style=wx.TE_MULTILINE)
        self.tc_text.Bind(wx.EVT_KEY_UP, self.__unlock_save)
        box_h_4.Add(self.tc_text, 1, wx.EXPAND)
        box_h_4.AddSpacer(5)
        box_v.Add(box_h_4, 1, wx.EXPAND)
        
        box_v.AddSpacer(5)
        
        # Reihe Abbrechen / Speichern
        box_h_5 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_5.AddSpacer(5)
        self.btn_abort = wx.Button(panel_main, -1, "Abbrechen", style=wx.BU_EXACTFIT, size = (100,-1))
        box_h_5.Add(self.btn_abort, 0)
        self.btn_save = wx.Button(panel_main, -1, "Speichern", style=wx.BU_EXACTFIT, size = (100,-1))
        self.btn_save.Disable()
        box_h_5.Add(self.btn_save, 0)
        box_h_5.AddSpacer(5)
        box_v.Add(box_h_5, 0, wx.ALIGN_RIGHT)
        
        box_v.AddSpacer(5)
        
        self.Bind(wx.EVT_BUTTON, self.OnBtnAbort, self.btn_abort)
        self.Bind(wx.EVT_BUTTON, self.OnBtnSave, self.btn_save)
        
        panel_main.SetAutoLayout(True)
        panel_main.SetSizer(box_v, False)
        panel_main.Layout()
        
        box_vm = wx.BoxSizer(wx.VERTICAL)
        box_vm.Add(panel_main, 1, wx.EXPAND)
        
        self.SetAutoLayout(True)
        self.SetSizer(box_vm, False)
        self.Layout()
        
        self.Centre()
        
        self.Bind(wx.EVT_CLOSE, self.OnClose)
        
    def __unlock_save(self, evt):
        self.btn_save.Enable()
        self.SAVE_LOCK = False
        
    def __lock_save(self, evt=None):
        self.btn_save.Disable()
        self.SAVE_LOCK = True
        
    def OnBtnAbort(self, evt):        
        self.Close()
    
    def OnBtnSave(self, evt):
        title = self.tc_title.GetValue()
        short_title = self.tc_short_title.GetValue()
        priority = self.ch_priority.GetStringSelection()
        text = self.tc_text.GetValue()
        
        if title == "":
            dlg = wx.MessageDialog(self, "Feld 'Titel' darf nicht leer sein.", 'wxTodo', wx.OK | wx.ICON_INFORMATION)
            dlg.ShowModal()
            dlg.Destroy()
            return
        
        if short_title == "":
            dlg = wx.MessageDialog(self, "Feld 'Kurz-Titel' darf nicht leer sein.", 'wxTodo', wx.OK | wx.ICON_INFORMATION)
            dlg.ShowModal()
            dlg.Destroy()
            return
        
        if priority == "":
            dlg = wx.MessageDialog(self, "Feld 'Priorität' muss gesetzt sein.", 'wxTodo', wx.OK | wx.ICON_INFORMATION)
            dlg.ShowModal()
            dlg.Destroy()
            return
        
        if text == "":
            dlg = wx.MessageDialog(self, "Feld 'Text' darf nicht leer sein.", 'wxTodo', wx.OK | wx.ICON_INFORMATION)
            dlg.ShowModal()
            dlg.Destroy()
            return
        
        self.db.todo_add(title, short_title, text, priority)
        
        dlg = wx.MessageDialog(self, "Daten wurden gespeichert.", 'wxTodo', wx.OK | wx.ICON_INFORMATION)
        dlg.ShowModal()
        dlg.Destroy()
        
        self.parent_frame._TodoList_refresh()
        
        self.Destroy()

    def OnClose(self, evt):
        if self.SAVE_LOCK == False:
            dlg = wx.MessageDialog(self, 'Fenster wirklich schließen? Alle getätigten Eingaben gehen verloren!',
                                   'wxTodo', wx.OK | wx.CANCEL | wx.ICON_WARNING)
            selected = dlg.ShowModal()
            dlg.Destroy()
            
            if selected == 5100:
                self.Destroy()
        else:
            self.Destroy()