# -*- coding: utf-8 -*-

import os
import wx
import re
import sys
import time

import config

def create(parent_frame, db, todo_id):
    return Frame2(parent_frame, db, todo_id)

class Frame2(wx.Frame):
    SAVE_LOCK = True
    
    def __init__(self, parent_frame, db, todo_id):
        self.db = db
        self.parent_frame = parent_frame
        self.todo_id = todo_id
        
        self.__gui_init()
        
        if self.todo_id > 0:
            self.__load_data()
        
    def __gui_init(self):
        wx.Frame.__init__(self, self.parent_frame, id=-1, name='wxTodo - Todo bearbeiten / ansehen',
                          size=wx.Size(700, 400), style=wx.DEFAULT_FRAME_STYLE, title='wxTodo - bearbeiten / ansehen - ID %s' % self.todo_id)
        
        self.SetMinSize((700, 400))
        
        panel_main = wx.Panel(self, -1)
        box_v = wx.BoxSizer(wx.VERTICAL)
        fontb = wx.Font(10, wx.NORMAL, wx.NORMAL, wx.FONTWEIGHT_BOLD)
        
        box_v.AddSpacer(5)
        
        # Reihe Titel
        box_h_1 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_1.AddSpacer(5)
        sttext1 = wx.StaticText(panel_main, -1, "Titel: ", size = (150,-1))
        box_h_1.Add(sttext1, 0, wx.CENTER)
        self.tc_title = wx.TextCtrl(panel_main, -1, "")
        self.tc_title.Bind(wx.EVT_KEY_UP, self.__unlock_save)
        box_h_1.Add(self.tc_title, 1, wx.EXPAND)
        box_h_1.AddSpacer(5)
        box_v.Add(box_h_1, 0, wx.EXPAND)
        
        box_v.AddSpacer(5)
        
        # Reihe Kurz-Titel
        box_h_2 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_2.AddSpacer(5)
        sttext2 = wx.StaticText(panel_main, -1, "Kurz-Titel: ", size = (150,-1))
        box_h_2.Add(sttext2, 0, wx.CENTER)
        self.tc_short_title = wx.TextCtrl(panel_main, -1, "")
        self.tc_short_title.Bind(wx.EVT_KEY_UP, self.__unlock_save)
        box_h_2.Add(self.tc_short_title, 1, wx.EXPAND)
        box_h_2.AddSpacer(5)
        box_v.Add(box_h_2, 0, wx.EXPAND)
        
        box_v.AddSpacer(5)
        
        # Reihe Priorität
        box_h_3 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_3.AddSpacer(5)
        sttext3 = wx.StaticText(panel_main, -1, "Priorität: ", size = (150,-1))
        box_h_3.Add(sttext3, 0, wx.CENTER)
        self.ch_priority = wx.Choice(panel_main, -1, size = (100,-1))
        self.ch_priority.Bind(wx.EVT_CHOICE, self.__unlock_save)
        for i in xrange(1,11):
            self.ch_priority.Append(str(i))
        box_h_3.Add(self.ch_priority, 0)
        box_h_3.AddSpacer(5)
        box_v.Add(box_h_3, 0, wx.EXPAND)
        
        box_v.AddSpacer(5)
        
        # Reihe Text
        box_h_4 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_4.AddSpacer(5)
        sttext4 = wx.StaticText(panel_main, -1, "Beschreibung: ", size = (150,-1))
        box_h_4.Add(sttext4, 0, wx.CENTER)
        self.tc_text = wx.TextCtrl(panel_main, -1, "", style=wx.TE_MULTILINE)
        self.tc_text.Bind(wx.EVT_KEY_UP, self.__unlock_save)
        box_h_4.Add(self.tc_text, 1, wx.EXPAND)
        box_h_4.AddSpacer(5)
        box_v.Add(box_h_4, 1, wx.EXPAND)
        
        box_v.AddSpacer(5)
        
        # Reihe Status
        box_h_5 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_5.AddSpacer(5)
        sttext5 = wx.StaticText(panel_main, -1, "Status: ", size = (150,-1))
        box_h_5.Add(sttext5, 0, wx.CENTER)
        items = []
        for item_id in config.TODO_AVAIL_STATUS:
            items.append(config.TODO_AVAIL_STATUS[item_id])
        self.rb_status = wx.RadioBox(panel_main, -1, "", (-1, -1), (-1, 40), items, 1, wx.NO_BORDER | wx.RA_SPECIFY_ROWS);
        self.rb_status.Bind(wx.EVT_RADIOBOX, self.__unlock_save)
        box_h_5.Add(self.rb_status, 0)
        box_h_5.AddSpacer(5)
        box_v.Add(box_h_5, 0, wx.EXPAND)
        
        box_v.AddSpacer(5)
        
        # Reihe Abbrechen / Speichern
        box_h_5_5 = wx.BoxSizer(wx.HORIZONTAL)
        
        box_v_2_2 = wx.BoxSizer(wx.VERTICAL)
        box_h_5_2 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_5_2.AddSpacer(5)
        self.btn_delete = wx.Button(panel_main, -1, "Löschen", style=wx.BU_EXACTFIT, size = (100,-1))
        box_h_5_2.Add(self.btn_delete, 1, wx.ALIGN_LEFT)
        box_v_2_2.Add(box_h_5_2, 1, wx.ALIGN_LEFT)
        box_h_5_5.Add(box_v_2_2, 0)
        
        box_v_5_2 = wx.BoxSizer(wx.VERTICAL)
        box_h_5 = wx.BoxSizer(wx.HORIZONTAL)
        box_h_5.AddSpacer(5)
        self.btn_abort = wx.Button(panel_main, -1, "Abbrechen", style=wx.BU_EXACTFIT, size = (100,-1))
        box_h_5.Add(self.btn_abort, 0)
        self.btn_save = wx.Button(panel_main, -1, "Speichern", style=wx.BU_EXACTFIT, size = (100,-1))
        self.btn_save.Disable()
        box_h_5.Add(self.btn_save, 0)
        self.btn_save_exit = wx.Button(panel_main, -1, "Speichern u. Schließen", style=wx.BU_EXACTFIT, size = (-1,-1))
        self.btn_save_exit.Disable()
        box_h_5.Add(self.btn_save_exit, 0)
        box_h_5.AddSpacer(5)
        box_v_5_2.Add(box_h_5, 1, wx.ALIGN_RIGHT)
        box_h_5_5.Add(box_v_5_2, 1)
        
        box_v.Add(box_h_5_5, 0, wx.EXPAND)
        
        box_v.AddSpacer(5)
        
        self.Bind(wx.EVT_BUTTON, self.OnBtnAbort, self.btn_abort)
        self.Bind(wx.EVT_BUTTON, self.OnBtnSave, self.btn_save)
        self.Bind(wx.EVT_BUTTON, self.OnBtnSaveExit, self.btn_save_exit)
        self.Bind(wx.EVT_BUTTON, self.OnBtnDelete, self.btn_delete)
        
        panel_main.SetAutoLayout(True)
        panel_main.SetSizer(box_v, False)
        panel_main.Layout()
        
        box_vm = wx.BoxSizer(wx.VERTICAL)
        box_vm.Add(panel_main, 1, wx.EXPAND)
        
        self.SetAutoLayout(True)
        self.SetSizer(box_vm, False)
        self.Layout()
        
        self.Centre()
        
        self.Bind(wx.EVT_CLOSE, self.OnClose)
        
    def __load_data(self):
        data = self.db.todo_get(self.todo_id)
        
        self.tc_title.SetValue(data['title'])
        self.tc_short_title.SetValue(data['short_title'])
        self.ch_priority.SetSelection(data['priority'] - 1)
        self.tc_text.SetValue(data['text'])
        self.rb_status.SetSelection(data['status'])
        
    def __unlock_save(self, evt):
        self.btn_save.Enable()
        self.btn_save_exit.Enable()
        self.SAVE_LOCK = False
        
    def __lock_save(self, evt=None):
        self.btn_save.Disable()
        self.btn_save_exit.Disable()
        self.SAVE_LOCK = True
        
    def OnBtnAbort(self, evt):        
        self.Close()
    
    def OnBtnSave(self, evt):
        title = self.tc_title.GetValue()
        short_title = self.tc_short_title.GetValue()
        priority = self.ch_priority.GetStringSelection()
        text = self.tc_text.GetValue()
        status = self.rb_status.GetSelection()
        
        if title == "":
            dlg = wx.MessageDialog(self, "Feld 'Titel' darf nicht leer sein.", 'wxTodo', wx.OK | wx.ICON_INFORMATION)
            dlg.ShowModal()
            dlg.Destroy()
            return
        
        if short_title == "":
            dlg = wx.MessageDialog(self, "Feld 'Kurz-Titel' darf nicht leer sein.", 'wxTodo', wx.OK | wx.ICON_INFORMATION)
            dlg.ShowModal()
            dlg.Destroy()
            return
        
        if priority == "":
            dlg = wx.MessageDialog(self, "Feld 'Priorität' muss gesetzt sein.", 'wxTodo', wx.OK | wx.ICON_INFORMATION)
            dlg.ShowModal()
            dlg.Destroy()
            return
        
        if text == "":
            dlg = wx.MessageDialog(self, "Feld 'Text' darf nicht leer sein.", 'wxTodo', wx.OK | wx.ICON_INFORMATION)
            dlg.ShowModal()
            dlg.Destroy()
            return
        
        self.db.todo_update(self.todo_id, title, short_title, text, priority, status)
        self.__lock_save()
        
        self.parent_frame._TodoList_refresh()
        
    def OnBtnSaveExit(self, evt):
        self.OnBtnSave(evt)
        
        dlg = wx.MessageDialog(self, "Daten wurden gespeichert.", 'wxTodo', wx.OK | wx.ICON_INFORMATION)
        dlg.ShowModal()
        dlg.Destroy()
        
        self.Destroy()
        
    def OnBtnDelete(self, evt):
        dlg = wx.MessageDialog(self, 'ACHTUNG! Dieses Todo wird unwiderruflich gelöscht!',
                               'wxTodo', wx.OK | wx.CANCEL | wx.ICON_WARNING)
        selected = dlg.ShowModal()
        dlg.Destroy()
        
        if selected == 5100:
            self.db.todo_del(self.todo_id)
            self.parent_frame._TodoList_refresh()
            self.Destroy()

    def OnClose(self, evt):
        if self.SAVE_LOCK == False:
            dlg = wx.MessageDialog(self, 'ACHTUNG! Alle getätigten Eingaben gehen verloren!',
                                   'wxTodo', wx.OK | wx.CANCEL | wx.ICON_WARNING)
            selected = dlg.ShowModal()
            dlg.Destroy()
            
            if selected == 5100:
                self.Destroy()
        else:
            self.Destroy()