# -*- coding: utf-8 -*-

import os
from pysqlite2 import dbapi2 as sqlite

class DBlite():
    todo_db_map = {0: "id", 1: "title", 2: "short_title", 3: "text", 4: "priority", 5: "status"}
    
    def __init__(self, name):
        new_db = True
        if os.path.isfile(name):
            new_db = False
        
        self.connection = sqlite.connect(name)
        self.cursor = self.connection.cursor()
        
        if new_db == True:
            self.cursor.execute('CREATE TABLE config (id INTEGER PRIMARY KEY AUTOINCREMENT, name VARCHAR(50) UNIQUE, value VARCHAR(200))')
            self.cursor.execute('CREATE TABLE todos (id INTEGER PRIMARY KEY AUTOINCREMENT, title VARCHAR(200), short_title VARCHAR(50), text TEXT, priority INTEGER, status INTEGER)')
        
        self.connection.commit()
            
    def config_get(self, name):
        self.cursor.execute('SELECT value FROM config WHERE name=?', (name,))
        try:
            return self.cursor.fetchone()[0]
        except:
            return ""
        
        
    def config_get_all_count(self):
        self.cursor.execute('SELECT COUNT(*) FROM config')
        return self.cursor.fetchall()[0][0]
        
    def config_get_all(self):
        data = {}
        self.cursor.execute('SELECT name, value FROM config order by name')
        for row in self.cursor.fetchall():
            data[row[0]] = row[1]
            
        return data
    
    def config_set(self, name, value):
        self.cursor.execute('SELECT COUNT(*) FROM config WHERE name=?', (name,))
        if self.cursor.fetchall()[0][0] == 1:
            self.cursor.execute('UPDATE config SET value=? WHERE name=?', (value, name))
        else:
            self.cursor.execute('INSERT INTO config VALUES (null, ?, ?)', (name, value))
            
        self.connection.commit()
        
    def config_del(self, name):
        self.cursor.execute('DELETE FROM config WHERE name=?', (name,))
        self.connection.commit()
        
    def todo_get(self, id):
        data = {}
        self.cursor.execute('SELECT * FROM todos WHERE id=?', (id,))
        try:
            tmp = self.cursor.fetchone()
            for map in self.todo_db_map:
                data[self.todo_db_map[map]] = tmp[map]
                
            return data
        except:
            return {}
        
    def todo_get_all_count(self):
        self.cursor.execute('SELECT COUNT(*) FROM todos')
        return self.cursor.fetchall()[0][0]
        
    def todo_get_all(self):
        data = {}
        self.cursor.execute('SELECT * FROM todos WHERE status not like 2')
        try:
            i=0
            for row in self.cursor.fetchall():
                tmp = {}
                for map in self.todo_db_map:
                    tmp[self.todo_db_map[map]] = row[map]
                
                data[i] = tmp    
                i = i + 1
                
            return data
        except:
            return {}
        
    def todo_add(self, title, short_title, text, priority):
        self.cursor.execute('INSERT INTO todos VALUES (null, ?, ?, ?, ?, 0)', (title, short_title, text, priority)) 
        self.connection.commit()
        
    def todo_update(self, id, title, short_title, text, priority, status):
        self.cursor.execute('UPDATE todos SET title=?, short_title=?, text=?, priority=?, status=? WHERE id=?', (title, short_title, text, priority, status, id)) 
        self.connection.commit()
        
    def todo_del(self, id):
        self.cursor.execute('DELETE FROM todos WHERE id=?', (id,))
        self.connection.commit()
        
    def close(self):
        self.cursor.close()
        self.connection.close()