# -*- coding: utf-8 -*-

import os
import wx
import re
import sys
import time

import f_todo_add
import f_todo_edit

import lib_com as libcom

class TrayIcon(wx.TaskBarIcon):
    TBMENU_RESTORE = wx.NewId()
    TBMENU_CLOSE   = wx.NewId()
    TBMENU_ADD_TODO   = wx.NewId()
    
    def __init__(self, frame, db):
        wx.TaskBarIcon.__init__(self)
        self.frame = frame
        self.db = db
        
        self.root = libcom.getProgramRoot()

        # Set the image
        self.SetIcon(wx.Icon(os.path.join(self.root, "tray.png"), wx.BITMAP_TYPE_PNG), u"wxTodo")
        self.imgidx = 1
        
        # bind some events
        self.Bind(wx.EVT_TASKBAR_LEFT_DCLICK, self.OnTaskBarActivateDClick)
        self.Bind(wx.EVT_TASKBAR_LEFT_DOWN, self.OnTaskBarActivate)
        self.Bind(wx.EVT_MENU, self.OnTaskBarActivate, id=self.TBMENU_RESTORE)
        self.Bind(wx.EVT_MENU, self.OnTaskBarClose, id=self.TBMENU_CLOSE)
        self.Bind(wx.EVT_MENU, self.OnwxTodoAdd, id=self.TBMENU_ADD_TODO)

    def CreatePopupMenu(self):
        menu = wx.Menu()
        menu.Append(self.TBMENU_RESTORE, u"Zeige Hauptfenster")
        menu.AppendSeparator()
        menu.Append(self.TBMENU_ADD_TODO, u"Todo hinzufügen")
        menu.AppendSeparator()
        if self.db.todo_get_all_count() == 0:
            noid = wx.NewId()
            menu.Append(noid, u"Keine Todos verhanden")
            menu.Enable(noid, 0)
        else:
            todos_all = self.db.todo_get_all()
            for item in todos_all:
                id = 10000 + todos_all[item]['id']
                menu.Append(id, todos_all[item]['short_title'])
                menu.Bind(wx.EVT_MENU, self.OnTodoSelect, id=id)
        menu.AppendSeparator()
        menu.Append(self.TBMENU_CLOSE, u"Beende Programm")
        return menu
    
    def OnwxTodoAdd(self, evt):
        self.f_todo_add = f_todo_add.create(self.frame, self.db)
        self.f_todo_add.Show()
        self.f_todo_add.SetFocus()
    
    def OnTaskBarActivate(self, evt):
        if self.frame.IsIconized():
            self.frame.Iconize(False)
        if not self.frame.IsShown():
            self.frame.Show(True)
        self.frame.Raise()
        
    def OnTaskBarActivateDClick(self, evt):
        if self.frame.IsShown():
            self.frame.Show(False)
            
        self.OnwxTodoAdd(evt)
        
    def OnTodoSelect(self, evt):
        todo_selected = evt.GetId() - 10000
        self.f_todo_edit = f_todo_edit.create(self.frame, self.db, todo_selected)
        self.f_todo_edit.Show()

    def OnTaskBarClose(self, evt):
        self.Destroy()
        wx.CallAfter(self.frame.Destroy)